Method: SQLite3::Database#execute

Defined in:
lib/sqlite3/database.rb

#execute(sql, *bind_vars) ⇒ Object

Executes the given SQL statement. If additional parameters are given, they are treated as bind variables, and are bound to the placeholders in the query.

Note that if any of the values passed to this are hashes, then the key/value pairs are each bound separately, with the key being used as the name of the placeholder to bind the value to.

The block is optional. If given, it will be invoked for each row returned by the query. Otherwise, any results are accumulated into an array and returned wholesale.

See also #execute2, #query, and #execute_batch for additional ways of executing statements.



180
181
182
183
184
185
186
187
188
189
# File 'lib/sqlite3/database.rb', line 180

def execute( sql, *bind_vars )
  prepare( sql ) do |stmt|
    result = stmt.execute( *bind_vars )
    if block_given?
      result.each { |row| yield row }
    else
      return result.inject( [] ) { |arr,row| arr << row; arr }
    end
  end
end